@@ -183,7 +183,7 @@ This main function repeatedly calls the polygon api every 1 seconds for 10 hours
 Arguments:
     - currency_pairs: Nested list with all the information about each currency pair
 """
-def main(currency_pairs, time):
+def mainFunc(currency_pairs, time):
     # The api key given by the professor
     key = "beBybSi8daPgsTp5yx5cHtHpYcrjp5Jq"
 
